# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grebble_flow/grpc/proto/processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grebble_flow/grpc/proto/processor.proto',
  package='grebble_flow.grpc.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'grebble_flow/grpc/proto/processor.proto\x12\x17grebble_flow.grpc.proto\"D\n\x0b\x46lowRequest\x12\x10\n\x08\x66lowName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x01(\t\"F\n\x0c\x46lowResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x12\n\nattributes\x18\x02 \x01(\t\x12\x11\n\tstreamEnd\x18\x03 \x01(\x08\x32g\n\tProcessor\x12Z\n\x07\x45xecute\x12$.grebble_flow.grpc.proto.FlowRequest\x1a%.grebble_flow.grpc.proto.FlowResponse\"\x00\x30\x01\x62\x06proto3'
)




_FLOWREQUEST = _descriptor.Descriptor(
  name='FlowRequest',
  full_name='grebble_flow.grpc.proto.FlowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowName', full_name='grebble_flow.grpc.proto.FlowRequest.flowName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowRequest.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowRequest.attributes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=136,
)


_FLOWRESPONSE = _descriptor.Descriptor(
  name='FlowResponse',
  full_name='grebble_flow.grpc.proto.FlowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='grebble_flow.grpc.proto.FlowResponse.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='grebble_flow.grpc.proto.FlowResponse.attributes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streamEnd', full_name='grebble_flow.grpc.proto.FlowResponse.streamEnd', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=208,
)

DESCRIPTOR.message_types_by_name['FlowRequest'] = _FLOWREQUEST
DESCRIPTOR.message_types_by_name['FlowResponse'] = _FLOWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowRequest = _reflection.GeneratedProtocolMessageType('FlowRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLOWREQUEST,
  '__module__' : 'grebble_flow.grpc.proto.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowRequest)
  })
_sym_db.RegisterMessage(FlowRequest)

FlowResponse = _reflection.GeneratedProtocolMessageType('FlowResponse', (_message.Message,), {
  'DESCRIPTOR' : _FLOWRESPONSE,
  '__module__' : 'grebble_flow.grpc.proto.processor_pb2'
  # @@protoc_insertion_point(class_scope:grebble_flow.grpc.proto.FlowResponse)
  })
_sym_db.RegisterMessage(FlowResponse)



_PROCESSOR = _descriptor.ServiceDescriptor(
  name='Processor',
  full_name='grebble_flow.grpc.proto.Processor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=210,
  serialized_end=313,
  methods=[
  _descriptor.MethodDescriptor(
    name='Execute',
    full_name='grebble_flow.grpc.proto.Processor.Execute',
    index=0,
    containing_service=None,
    input_type=_FLOWREQUEST,
    output_type=_FLOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSOR)

DESCRIPTOR.services_by_name['Processor'] = _PROCESSOR

# @@protoc_insertion_point(module_scope)
